==> ispell-3.3.01.tar.gz: ispell-3.3.01/version.h <==
#ifndef VERSION_H_INCLUDED
#define VERSION_H_INCLUDED
/*
 * Since the strings in this file are printed out when the "-v" switch is
 * given to ispell, you may want to translate them into your native language.
 * However, any translation of these strings MUST accurately preserve the
 * legal rights under international law;  you may wish to consult a lawyer
 * about this since you will be responsible for the results of any
 * incorrect translation.
 */

static char * Version_ID[] = {
    "@(#) International Ispell Version 3.3.01 1 May 2005",
    "@(#) Copyright (c), 1983, by Pace Willisson",
    "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
    "@(#) 2001, 2002, 2005 by Geoff Kuenning, Claremont, CA.",
    "@(#) All rights reserved.",
    "@(#)",
    "@(#) The official ispell Web site is at:",
    "@(#)",
    "@(#)     http://www.lasr.cs.ucla.edu/geoff/ispell.html",
    "@(#)",
    "@(#) You should always check that site to see whether you have the",
    "@(#) latest version of ispell.",
    "@(#)",
    "@(#) Report bugs to ispell-bugs@itcorp.com.  Report Emacs-related bugs",
    "@(#) to ispell-el-bugs@itcorp.com.",
    "@(#)",
    "@(#) Redistribution and use in source and binary forms, with or without",
    "@(#) modification, are permitted provided that the following conditions",
    "@(#) are met:",
    "@(#)",
    "@(#) 1. Redistributions of source code must retain the above copyright",
    "@(#)    notice, this list of conditions and the following disclaimer.",
    "@(#) 2. Redistributions in binary form must reproduce the above",
    "@(#)    copyright notice, this list of conditions and the following",
    "@(#)    disclaimer in the documentation and/or other materials provided",
    "@(#)    with the distribution.",
    "@(#) 3. All modifications to the source code must be clearly marked as",
    "@(#)    such.  Binary redistributions based on modified source code",
    "@(#)    must be clearly marked as modified versions in the documentation",
    "@(#)    and/or other materials provided with the distribution.",
    "@(#) 4. The code that causes the 'ispell -v' command to display a",
    "@(#)    prominent link to the official ispell Web site may not be",
    "@(#)    removed.",
    "@(#) 5. The name of Geoff Kuenning may not be used to endorse or promote",
    "@(#)    products derived from this software without specific prior",
    "@(#)    written permission.",
    "@(#)",
    "@(#) THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS",
    "@(#) IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT",
    "@(#) LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS",
    "@(#) FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF",
    "@(#) KUENNING OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,",
    "@(#) INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES",
    "@(#) (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR",
    "@(#) SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)",
    "@(#) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,",
    "@(#) STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)",
    "@(#) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED",
    "@(#) OF THE POSSIBILITY OF SUCH DAMAGE.",
    NULL
};

static char RCS_Version_ID[] =
    "$Id: version.h,v 1.58 2005/05/01 23:21:59 geoff Exp $";

#endif /* VERSION_H_INCLUDED */

==> ispell_3.4.01.orig.tar.gz: ispell-3.4.01/version.h <==
#ifndef VERSION_H_INCLUDED
#define VERSION_H_INCLUDED
/*
 * Since the strings in this file are printed out when the "-v" switch is
 * given to ispell, you may want to translate them into your native language.
 * However, any translation of these strings MUST accurately preserve the
 * legal rights under international law;  you may wish to consult a lawyer
 * about this since you will be responsible for the results of any
 * incorrect translation.
 */

static char * Version_ID[] = {
    "@(#) International Ispell Version 3.4.01 30 Dec 2020",
    "@(#) Copyright (c), 1983, by Pace Willisson",
    "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
    "@(#) 2001, 2002, 2005, 2015, 2020 by Geoff Kuenning, Claremont, CA.",
    "@(#) All rights reserved.",
    "@(#)",
    "@(#) The official ispell Web site is at:",
    "@(#)",
    "@(#)     http://www.cs.hmc.edu/geoff/ispell.html",
    "@(#)",
    "@(#) You should always check that site to see whether you have the",
    "@(#) latest version of ispell.",
    "@(#)",
    "@(#) Report bugs to ispell-bugs@itcorp.com.  Report Emacs-related bugs",
    "@(#) to ispell-el-bugs@itcorp.com.",
    "@(#)",
    "@(#) Redistribution and use in source and binary forms, with or without",
    "@(#) modification, are permitted provided that the following conditions",
    "@(#) are met:",
    "@(#)",
    "@(#) 1. Redistributions of source code must retain the above copyright",
    "@(#)    notice, this list of conditions and the following disclaimer.",
    "@(#) 2. Redistributions in binary form must reproduce the above",
    "@(#)    copyright notice, this list of conditions and the following",
    "@(#)    disclaimer in the documentation and/or other materials provided",
    "@(#)    with the distribution.",
    "@(#) 3. All modifications to the source code must be clearly marked as",
    "@(#)    such.  Binary redistributions based on modified source code",
    "@(#)    must be clearly marked as modified versions in the documentation",
    "@(#)    and/or other materials provided with the distribution.",
    "@(#) 4. The code that causes the 'ispell -v' command to display a",
    "@(#)    prominent link to the official ispell Web site may not be",
    "@(#)    removed.",
    "@(#) 5. The name of Geoff Kuenning may not be used to endorse or promote",
    "@(#)    products derived from this software without specific prior",
    "@(#)    written permission.",
    "@(#)",
    "@(#) THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS",
    "@(#) IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT",
    "@(#) LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS",
    "@(#) FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF",
    "@(#) KUENNING OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,",
    "@(#) INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES",
    "@(#) (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR",
    "@(#) SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)",
    "@(#) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,",
    "@(#) STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)",
    "@(#) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED",
    "@(#) OF THE POSSIBILITY OF SUCH DAMAGE.",
    NULL
};

static char RCS_Version_ID[] =
    "$Id: version.h,v 1.61 2020-12-30 22:33:42-08 geoff Exp $";

#endif /* VERSION_H_INCLUDED */
